#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer_1 = __importDefault(require("inquirer"));
const request_1 = require("./request");
const resolveConfig_1 = require("./resolveConfig");
const generate_1 = require("./generate");
const __config__ = (0, resolveConfig_1.resolveConfig)();
(async function () {
    // 配置了toolKey 走匿名接口
    if (!!__config__.toolKey) {
        // 生成ts-api
        (0, generate_1.generate)(__config__.toolKey);
        return;
    }
    // 登录
    await (0, request_1.login)();
    let currentGroups = null;
    let currentProject = null;
    if (!__config__.pgid) {
        // 获取项目组
        const res = await (0, request_1.getProgroups)();
        const answer = await inquirer_1.default.prompt([
            {
                type: "list",
                message: "请选择项目组: ",
                choices: res.map((v) => v.name),
                name: "projectGroup",
                default: "",
            },
        ]);
        currentGroups = res.find((v) => v.name === answer.projectGroup);
        __config__.pgid = currentGroups.id;
    }
    // 获取项目列表
    const res = await (0, request_1.getProjects)(__config__.pgid);
    if (__config__.pid) {
        currentProject = res.find((v) => v.id === Number(__config__.pid));
    }
    else {
        const answer = await inquirer_1.default.prompt([
            {
                type: "list",
                message: "请选择项目组: ",
                choices: res.map((v) => v.name),
                name: "project",
                default: "",
            },
        ]);
        currentProject = res.find((v) => v.name === answer.project);
        __config__.pid = currentProject.id;
    }
    // 生成ts-api
    (0, generate_1.generate)(currentProject.toolKey);
    // 退出登录
    await (0, request_1.logout)();
})();
//# sourceMappingURL=index.js.map